use strict;
use warnings;

package Test::StructuredObject::NonTest;
BEGIN {
  $Test::StructuredObject::NonTest::VERSION = '0.01000009';
}

# ABSTRACT: A L<< C<CodeStub>|Test::StructuredObject::CodeStub >> representing executable but non-test code.

use Moose;
extends 'Test::StructuredObject::CodeStub';
use namespace::autoclean;


has code => ( isa => 'CodeRef', required => 1, is => 'rw' );

## no critic ( ProhibitUnusedPrivateSubroutines )

sub _label {
  my $self = shift;
  return __PACKAGE__ . '(' . shift . ')';
}
no Moose;
__PACKAGE__->meta->make_immutable;

1;


__END__
=pod

=head1 NAME

Test::StructuredObject::NonTest - A L<< C<CodeStub>|Test::StructuredObject::CodeStub >> representing executable but non-test code.

=head1 VERSION

version 0.01000009

=head1 ATTRIBUTES

=head2 code

The C<coderef> to execute during L<< C<run>|Test::StructuredObject::CodeStub/run >>

=head1 AUTHOR

Kent Fredric <kentnl@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2010 by Kent Fredric <kentnl@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

